@@ -9,8 +9,19 @@ import mbedtls.cipher as cipher
 import mbedtls.exceptions as exceptions
 import mbedtls.hash as hash
 import mbedtls.hmac as hmac
+import mbedtls.hkdf as hkdf
 import mbedtls.pk as pk
 import mbedtls.tls as tls
+import mbedtls.x509 as x509
 
 
-__all__ = ("cipher", "exceptions", "hash", "hmac", "pk", "tls", "version")
+__all__ = (
+    "cipher",
+    "exceptions",
+    "hash",
+    "hmac",
+    "pk",
+    "tls",
+    "version",
+    "x509",
+)
